@@ -941,13 +941,14 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def OpenPositions(self,broker: str,symbol: str="",product: str="",api_key: str="default", api_secret: str="default"):
+    def OpenPositions(self,broker: str,symbol: str="",exchange: str="",product: str="",api_key: str="default", api_secret: str="default"):
         """This function display's the open positions of the specified broker .
 
     Parameters
     ----------
         broker (str): The name of the broker short code. (e.g ab - aliceblue,an - angelone, fs - firstock, up- upstox, ze- zerodha ). Refer API Docs appendix for complete broker code.
         symbol(str, optional): The symbol for the order.
+        exchange (str): The name of the exchange (NSE,NFO,BSE,BFO,MCX,CDS).
         product (str, optional): The product type for the order (e.g. "CNC,MIS,NRML").
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
@@ -986,13 +987,14 @@ class api:
         return (r.json())
     
 
-    def AllPositions(self,broker: str,symbol: str="",product: str="",api_key: str="default", api_secret: str="default"):
+    def AllPositions(self,broker: str,symbol: str="",exchange: str="",product: str="",api_key: str="default", api_secret: str="default"):
         """This function display's the open positions of the specified broker .
 
     Parameters
     ----------
         broker (str): The name of the broker short code. (e.g ab - aliceblue,an - angelone, fs - firstock, up- upstox, ze- zerodha ). Refer API Docs appendix for complete broker code.
         symbol(str, optional): The symbol for the order.
+        exchange (str): The name of the exchange (NSE,NFO,BSE,BFO,MCX,CDS).
         product (str, optional): The product type for the order (e.g. "CNC,MIS,NRML").
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
